==> haskell-yesod-persistent-1.6.0.8-265-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-IQ90eIlgudXCbOwPIHnemW
key:                  yesod-persistent-1.6.0.8-IQ90eIlgudXCbOwPIHnemW
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  c9b922fcfccb812c8ed01ef4f8db231c
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.2.8/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-IQ90eIlgudXCbOwPIHnemW
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s
    persistent-2.14.5.1-9xnFRv8rkde2AoeFkZgfdg
    resource-pool-0.2.3.2-GoxnmSc4Q995sKTSDuBd5z
    resourcet-1.2.6-L3rnNUXQIyNIGkCgFQVXFM transformers-0.5.6.2
    yesod-core-1.6.25.1-9rrrUYRyo8O7gXoyWkJvCv

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.6.0.8-294-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-L7wBT0Q5rWw1NmYKJcD7zp
key:                  yesod-persistent-1.6.0.8-L7wBT0Q5rWw1NmYKJcD7zp
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  01475064de3b7f10bb40247628024a30
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.2.8/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-L7wBT0Q5rWw1NmYKJcD7zp
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    persistent-2.14.5.1-18Wt2qDE1QV8HG32f1oXLN
    resource-pool-0.2.3.2-2ghaoAEpV2r22WQ70y4rca
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD transformers-0.5.6.2
    yesod-core-1.6.26.0-KQQ0GNaYNxp6R63eniD4G4

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
